@@ -26,8 +26,8 @@ function deal_info(){
             description: proj_desc, 
             author:author,
             scripts: {
-                build:"atom-engine build",
-                server:"atom-engine server"
+                build: 'atom-engine build',
+                server: 'atom-engine server'
             }   
         },null,2));
     console.log('Init end>>>>>>>>>>>>>>>>>>>');
